---
template: mainpanel
source_form: markdown
name: Trello Cardlist Tasks Done
updated: October 2016
title: Trello Cardlist Tasks Done
---
### Tasks Done

* 0\.0.22 - - - - - (tasks)
* 239\. 0.0.22 Release tasks
* 0\.0.22 - - - - - (tasks)
* 239\. 0.0.21 Release tasks
* 0\.0.20 - - - - - (tasks)
* Update changelog
* Add newsletter subscription to site info
* 234\. Replicate *target* release issues for 0.0.20 into github
* 235\. Newsletter for sparkslabs projects exists.
* 236\. Re-order trello lists by left to right order to make more usable
* 237\. Tweak git repo
* 0\.0.19 - - - - - (tasks)
* 0\.0.18 - - - - - (tasks)
* Package for release and release (DONE)
* Cleanup clib packaging
* 0\.0.17 - - - - - (tasks)
* 10\. Decide whether to add functionality of bin/pyxie-dev is in core
* 0\.0.16 - - - - - (tasks)
* 1\. Number Cards in backlog.
* 7\. For Release: 0.0.16
* 192\. Trello snapshot generation escapes task numbers.
* 68\. Write Bump Versions Script.
* 69\. Re-prioritise backlog for 0.0.16
* 70\. Breakdown features needed for a release script
* 0\.0.15 - - - - - (tasks)
* 72\. For Release: 0.0.15
* 73\. Bump Versions
* 0\.0.14 - - - - - (tasks)
* 81\. For Release: 0.0.14
* 0\.0.13 - - - - - (tasks)
* 89\. For Release: 0.0.13
* 90\. Decide on Python Modulo operator?
* 91\. Bump Versions
* 0\.0.12 - - - - - (tasks)
* 101\. Update language status for 0.0.12
* 102\. BUG: Parser generates far too many "empty statements"
* 103\. Update language status for 0.0.11
* 104\. Check docs in pyxie/__init__.py match 0.0.12 Release
* 105\. Bump Versions
* 106\. Push rebased site to github/live
* 107\. Site for Pyxie, should link to language spec -- http://www.sparkslabs.com/Pyxie/language-spec.md
* 0\.0.11 - - - - - (tasks)
* 112\. For release: 0.0.11
* 113\. Check docs in pyxie/__init__.py match 0.0.11 Release
* 114\. Bump Versions
* 0\.0.10 - - - - - (tasks)
* 131\. For release: 0.0.10
* 132\. Check that programs that compile produce expected code
* 134\. Check docs in pyxie/__init__.py match 0.0.10 Release
* 135\. Update test target in makefile to match new pyxie args
* 136\. Bump Versions
* 137\. Order of functions in pynode matches grammar - making it easier to follow
* 138\. Document current parsing status more accurately
* 0\.0.9 - - - - - (tasks)
* 148\. Check that debian package being built/created does actually contains what's wanted
* 149\. Check that the tar ball being built/created for pypi actually contains what you want
* 150\. Version number bumped
* 0\.0.8 - - - - - (tasks earlier)
* 175\. Why the project doesn't use the standard python compiler/AST module
* 176\. Break down language features into specific feature tasks - for initial feature set
* 177\. pyxie compiler now accepts runtime options to control what tests get compiled
* 178\. Changelog for initial releases
* 179\. Initial language spec
* 180\. Packaging for pypi exists
* 181\. Packaging via PPA exists
* 182\. The CST for baseline Python code is simplified
* 183\. Initial testing infrastructure in place
* 184\. Private github repo for Pyxie
* 185\. initial README for Pyxie
* 186\. Pyxie 0.0.1 Released
* 187\. Pyxie 0.0.2 Released
* 188\. Pyxies 0.0.3 Released
* 189\. Pyxie 0.0.4 Released
* 190\. Pyxie 0.0.5 Released
* 191\. Bump Versions
